searchData={"items":[{"type":"module","title":"LED","doc":"Control LEDs or relays. A simple library with some artful gimmicks.\n\nThis library is a simple, convenient wrapper around [Circuits.GPIO](https://hexdocs.pm/circuits_gpio/)\nfor controlling LEDs or relays. Beyond basic on/off control, it enables artful, experimental,\nand even random noise light effects through overlapping repeating patterns — offering creative flexibility.\n\n## ✨ Features\n\n- ⚡ Control single LEDs or relays on GPIO pins\n- ✔ Easy on/off control\n- ⏰ Blink and repeat patterns with configurable intervals and counts\n- 💡 Toggle LED state\n- 🎛️ Optional named LED processes for multiple devices\n- Supports overlapping repeat patterns for creative effects\n- Defaults to GPIO pin `22` with LED initially on","ref":"LED.html"},{"type":"module","title":"Installation - LED","doc":"Add to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:led, \"~> 0.1.0\"}\n  ]\nend\n```\n\n## 🛠 Usage","ref":"LED.html#module-installation"},{"type":"module","title":"Start an LED - LED","doc":"* Default (gpio_pin: 22, initially on):\n\n```elixir\n{:ok, _pid} = LED.start_link()\n```\n\n* Named (gpio_pin: 23, initially off):\n\n```elixir\n{:ok, _pid} = LED.start_link(name: :green_led, gpio_pin: 23, initial_value: 0)\n```","ref":"LED.html#module-start-an-led"},{"type":"module","title":"Turn it on or off - LED","doc":"* Default:\n\n```elixir\nLED.on()\nLED.off()\n```\n* Named:\n\n```elixir\nLED.on(:green_led)\nLED.off(:green_led)\n```","ref":"LED.html#module-turn-it-on-or-off"},{"type":"module","title":"Toggle LED - LED","doc":"```elixir\nLED.toggle()\nLED.toggle(:green_led)\n```","ref":"LED.html#module-toggle-led"},{"type":"module","title":"Set state directly - LED","doc":"```elixir\nLED.set(0, :green_led)  # Off\nLED.set(1, :green_led)  # On\n```\n### ⏰ Blink LED\n\n* Blink indefinitely at 2 Hz (250ms interval):\n\n```elixir\nLED.blink()\nLED.blink(name: :green_led)\n```\n\n* Blink LED on default/`:green_led` 10 times, toggling every 500 ms:\n\n```elixir\nLED.blink(interval: 500, times: 10)\nLED.blink(name: :green_led, interval: 500, times: 10)\n```","ref":"LED.html#module-set-state-directly"},{"type":"module","title":"Repeat blinking (overlapping allowed) - LED","doc":"* Start a repeating blink pattern on default/`:green_led` every 300 ms indefinitely:\n\n```elixir\nLED.repeat(interval: 300)\nLED.repeat(name: :green_led, interval: 300)\n```\n* Overlay multiple blinking patterns (polyrhythmic effect):\n\n```elixir\nLED.repeat(interval: 400, times: 5)\nLED.repeat(interval: 700, times: 3)\nLED.repeat(name: :green_led, interval: 400, times: 5)\nLED.repeat(name: :green_led, interval: 700, times: 3)\n```","ref":"LED.html#module-repeat-blinking-overlapping-allowed"},{"type":"module","title":"Cancel blinking timers - LED","doc":"Stop all blinking/repeating timers on default/`:green_led`:\n\n```elixir\nLED.cancel_timers()\nLED.cancel_timers(:green_led)\n```\n\n  > #### Note on use with relay {: .tip}\n  > When using a relay, check its datasheet\n  > for minimum switch times to avoid damage or malfunction.","ref":"LED.html#module-cancel-blinking-timers"},{"type":"function","title":"LED.blink/1","doc":"Starts or updates regular blinking for the LED.\n\nAccepts keyword options:\n\n  * `:name` – (atom) GenServer name of the LED. Defaults to the module name.\n  * `:interval` – (integer) Blink interval in milliseconds. Default is `250` (≈2 Hz).\n  * `:times` – (integer) Number of blinks. Default is `-1` for continuous blinking.\n\nThis will cancel any existing blinking or repeat timers before starting.\n\nUse `repeat/1` instead for experimental or overlapping blink patterns.","ref":"LED.html#blink/1"},{"type":"function","title":"Examples - LED.blink/1","doc":"iex> LED.blink()\n    :ok\n\n    iex> LED.blink(name: :green_led, interval: 500, times: 10)\n    :ok","ref":"LED.html#blink/1-examples"},{"type":"function","title":"LED.cancel_timers/1","doc":"Cancels all active timers associated with the LED process.\n\nThis stops any ongoing `blink/1` or `repeat/1` patterns by clearing all stored\n`timer_refs`. Use this to reset the LED's timing behavior before issuing new\ncommands.\n\n`name` – (optional) the GenServer name of the LED; defaults to the module.","ref":"LED.html#cancel_timers/1"},{"type":"function","title":"Examples - LED.cancel_timers/1","doc":"iex> LED.cancel_timers()\n\n    iex> LED.cancel_timers(:led_green)","ref":"LED.html#cancel_timers/1-examples"},{"type":"function","title":"LED.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LED.html#child_spec/1"},{"type":"function","title":"LED.is_lit?/1","doc":"Returns `true` if the LED is currently on (`state == 1`), otherwise returns `false`.\n\nAccepts an optional `name` argument for the GenServer process name set via `start_link/1`.\nDefaults to the module name.","ref":"LED.html#is_lit?/1"},{"type":"function","title":"Examples - LED.is_lit?/1","doc":"iex> {:ok, _pid} = LED.start_link()\n    iex> LED.on()\n    iex> LED.is_lit?()\n    true\n    iex> LED.off()\n    iex> LED.is_lit?()\n    false\n\n    iex> {:ok, _pid} = LED.start_link(gpio_pin: 23, name: :led_pink)\n    iex> LED.on(:led_pink)\n    iex> LED.is_lit?(:led_pink)\n    true\n    iex> LED.off(:led_pink)\n    iex> LED.is_lit?(:led_pink)\n    false","ref":"LED.html#is_lit?/1-examples"},{"type":"function","title":"LED.off/1","doc":"Turns the LED off by setting its GPIO state to `0`.\n\nAccepts an optional `name` argument to control a specific LED process started\nwith `start_link/1`. If no `name` is given, the default module name is used.\n\nCalling this will cancel any active blinking or repeat timers before switching\nthe LED off.","ref":"LED.html#off/1"},{"type":"function","title":"Examples - LED.off/1","doc":"Turn off the default LED (GPIO pin 22):\n\n    iex> LED.off()\n\nStart and turn off a named LED on GPIO pin 23:\n\n    iex> {:ok, _pid} = LED.start_link(gpio_pin: 23, name: :led_yellow)\n    iex> LED.off(:led_yellow)","ref":"LED.html#off/1-examples"},{"type":"function","title":"LED.on/1","doc":"Turns the LED on by setting its GPIO state to `1`.\n\nAccepts an optional `name` argument to control a specific LED process started\nwith `start_link/1`. If no `name` is given, the default module name is used.\n\nCalling this will cancel any active blinking or repeat timers before switching\nthe LED on.","ref":"LED.html#on/1"},{"type":"function","title":"Examples - LED.on/1","doc":"Turn on the default LED (GPIO pin 22):\n\n    iex> LED.on()\n\nStart and turn on a named LED on GPIO pin 23:\n\n    iex> {:ok, _pid} = LED.start_link(gpio_pin: 23, name: :led_green)\n    iex> LED.on(:led_green)","ref":"LED.html#on/1-examples"},{"type":"function","title":"LED.repeat/1","doc":"Starts a repeating blink pattern on the LED.\n\nUnlike `blink/1`, this function allows multiple overlapping patterns,\nenabling experimental or polyrhythmic effects. Each call creates a new\ntimer without cancelling existing ones.\n\nCan be manually canceled using `cancel_timers/1`.\n\nUseful for creative setups or layered visual rhythms. For best visibility,\nuse intervals greater than 10ms.","ref":"LED.html#repeat/1"},{"type":"function","title":"Options - LED.repeat/1","doc":"* `:name` – (atom) GenServer name of the LED. Defaults to the module name.\n  * `:interval` – (integer) Interval in milliseconds between toggles. Default: `250` (≈2 Hz).\n  * `:times` – (integer) Number of blinks. `-1` means infinite. Default: `-1`.\n\nIf you want predictable, single-pattern blinking, use `blink/1` instead.","ref":"LED.html#repeat/1-options"},{"type":"function","title":"Examples - LED.repeat/1","doc":"iex> LED.repeat()\n    :ok\n    iex> LED.repeat(interval: 969)\n    :ok\n    iex> LED.cancel_timers()\n\n    iex> LED.repeat(name: :green_led, interval: 900)\n    :ok\n    iex> LED.repeat(name: :green_led, interval: 690)\n    :ok\n    iex> LED.cancel_timers(:green_led)","ref":"LED.html#repeat/1-examples"},{"type":"function","title":"LED.set/2","doc":"Sets the LED to a specific state: `1` for **on**, `0` for **off**.\n\nAny active blinking or repeat timers will be canceled before setting the state,\nensuring full manual control.\n\nAccepts an optional `name` argument to target a specific LED GenServer.\nIf omitted, it uses the default module name.","ref":"LED.html#set/2"},{"type":"function","title":"Examples - LED.set/2","doc":"Turn off and on the default LED:\n\n    iex> LED.set(0)\n    iex> LED.set(1)\n\nControl a named LED:\n\n    iex> {:ok, _pid} = LED.start_link(gpio_pin: 23, name: :led_red)\n    iex> LED.set(0, :led_red)\n    iex> LED.set(1, :led_red)","ref":"LED.html#set/2-examples"},{"type":"function","title":"LED.start_link/1","doc":"Starts the LED GenServer.\n\nAccepts keyword arguments in `init_args` to configure the LED:\n\n  * `:name` – (atom) Optional name for the GenServer (used for referencing multiple LEDs)\n  * `:gpio_pin` – (integer) GPIO pin to control; defaults to `22`\n  * `:initial_value` – (0 or 1) Initial LED state; `0` = off, `1` = on (default: `1`)","ref":"LED.html#start_link/1"},{"type":"function","title":"Examples - LED.start_link/1","doc":"Start the default LED:\n\n    iex> {:ok, _pid} = LED.start_link()\n\nStart a named LED on pin 23, initially off.\nYou can control it with:\n\n    iex> {:ok, _pid} = LED.start_link(name: :green_led, gpio_pin: 23, initial_value: 0)\n    iex> LED.on(:green_led)\n    iex> LED.is_lit?(:green_led)\n    true","ref":"LED.html#start_link/1-examples"},{"type":"function","title":"LED.timer_start/3","doc":"Starts a blinking timer that toggles the LED at a given interval and for a\ngiven number of times.\n\n- `interval` – blinking interval in milliseconds.\n- `times` – how often to toggle the LED. Use `-1` for infinite blinking.\n\nUse `cancel_timers/1` to stop the blinking manually.","ref":"LED.html#timer_start/3"},{"type":"function","title":"Examples - LED.timer_start/3","doc":"Blink the default LED continuously every 200ms:\n\n    iex> LED.timer_start(200, -1)\n\nBlink a named LED 5 times every 300ms:\n\n    iex> LED.timer_start(300, 5, :led_blue)","ref":"LED.html#timer_start/3-examples"},{"type":"function","title":"LED.toggle/1","doc":"Toggles the LED: turns it off if on, and on if off.","ref":"LED.html#toggle/1"},{"type":"function","title":"Examples - LED.toggle/1","doc":"iex> {:ok, _pid} = LED.start_link()\n    iex> LED.on()\n    iex> LED.toggle()\n    iex> LED.is_lit?()\n    false\n\n    iex> {:ok, _pid} = LED.start_link(gpio_pin: 23, name: :green_led)\n    iex> LED.off(:green_led)\n    iex> LED.toggle(:green_led)\n    iex> LED.is_lit?(:green_led)\n    true","ref":"LED.html#toggle/1-examples"},{"type":"module","title":"LED.Timer","doc":"Timer helper functions for managing LED blinking and repeating patterns.\n\nProvides mechanisms to send timed messages for blinking intervals,\nincluding support for infinite repeats and countdowns.","ref":"LED.Timer.html"},{"type":"function","title":"LED.Timer.cancel/1","doc":"Cancels a list of timer references to stop scheduled timer messages.\n\n- `timer_refs` is a list of references returned by `Process.send_after/3`.\n- If a `nil` timer_ref is encountered, logs a debug message and skips cancellation.","ref":"LED.Timer.html#cancel/1"},{"type":"function","title":"LED.Timer.send_timer/1","doc":"Schedules the next timer message for LED blinking or repeating patterns.\n\n- Accepts a tuple `{state, interval, times}` where:\n  - `state` is `0` (off) or `1` (on).\n  - `interval` is the delay in milliseconds before sending the next message.\n  - `times` is the number of remaining toggles; `-1` means infinite repeats.\n\n- If `times` is `-1`, schedules the timer infinitely.\n- If `times` is `0`, does nothing (no timer scheduled).\n\n- If `state` is `0`, decrements `times` and schedules the next timer.\n- If `state` is `1`, schedules the next timer without decrementing `times`.\n\nReturns the timer reference or `nil` if no timer is scheduled.","ref":"LED.Timer.html#send_timer/1"},{"type":"extras","title":"🟢 LED","doc":"# 🟢 LED \n\nControl LEDs or relays. A simple library with some artful gimmicks.\n\nThis library is a simple, convenient wrapper around [Circuits.GPIO](https://hexdocs.pm/circuits_gpio/)\nfor controlling LEDs or relays. Beyond basic on/off control, it enables artful, experimental,\nand even random noise light effects through overlapping repeating patterns — offering creative flexibility.\n\n## ✨ Features\n\n- ⚡ Control single LEDs or relays on GPIO pins\n- ✔ Easy on/off control\n- ⏰ Blink and repeat patterns with configurable intervals and counts\n- 💡 Toggle LED state\n- 🎛️ Optional named LED processes for multiple devices\n- Supports overlapping repeat patterns for creative effects\n- Defaults to GPIO pin `22` with LED initially on","ref":"readme.html"},{"type":"extras","title":"Installation - 🟢 LED","doc":"Add to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:led, \"~> 0.1.0\"}\n  ]\nend\n```\n\n## 🛠 Usage","ref":"readme.html#installation"},{"type":"extras","title":"Start an LED - 🟢 LED","doc":"* Default (gpio_pin: 22, initially on):\n\n```elixir\n{:ok, _pid} = LED.start_link()\n```\n\n* Named (gpio_pin: 23, initially off):\n\n```elixir\n{:ok, _pid} = LED.start_link(name: :green_led, gpio_pin: 23, initial_value: 0)\n```","ref":"readme.html#start-an-led"},{"type":"extras","title":"Turn it on or off - 🟢 LED","doc":"* Default:\n\n```elixir\nLED.on()\nLED.off()\n```\n* Named:\n\n```elixir\nLED.on(:green_led)\nLED.off(:green_led)\n```","ref":"readme.html#turn-it-on-or-off"},{"type":"extras","title":"Toggle LED - 🟢 LED","doc":"```elixir\nLED.toggle()\nLED.toggle(:green_led)\n```","ref":"readme.html#toggle-led"},{"type":"extras","title":"Set state directly - 🟢 LED","doc":"```elixir\nLED.set(0, :green_led)  # Off\nLED.set(1, :green_led)  # On\n```\n### ⏰ Blink LED\n\n* Blink indefinitely at 2 Hz (250ms interval):\n\n```elixir\nLED.blink()\nLED.blink(name: :green_led)\n```\n\n* Blink LED on default/`:green_led` 10 times, toggling every 500 ms:\n\n```elixir\nLED.blink(interval: 500, times: 10)\nLED.blink(name: :green_led, interval: 500, times: 10)\n```","ref":"readme.html#set-state-directly"},{"type":"extras","title":"Repeat blinking (overlapping allowed) - 🟢 LED","doc":"* Start a repeating blink pattern on default/`:green_led` every 300 ms indefinitely:\n\n```elixir\nLED.repeat(interval: 300)\nLED.repeat(name: :green_led, interval: 300)\n```\n* Overlay multiple blinking patterns (polyrhythmic effect):\n\n```elixir\nLED.repeat(interval: 400, times: 5)\nLED.repeat(interval: 700, times: 3)\nLED.repeat(name: :green_led, interval: 400, times: 5)\nLED.repeat(name: :green_led, interval: 700, times: 3)\n```","ref":"readme.html#repeat-blinking-overlapping-allowed"},{"type":"extras","title":"Cancel blinking timers - 🟢 LED","doc":"Stop all blinking/repeating timers on default/`:green_led`:\n\n```elixir\nLED.cancel_timers()\nLED.cancel_timers(:green_led)\n```\n\n  > #### Note on use with relay {: .tip}\n  > When using a relay, check its datasheet\n  > for minimum switch times to avoid damage or malfunction.","ref":"readme.html#cancel-blinking-timers"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}